/** \file textconf.h
 *  \brief Header: prints features specific for this build
 */

#ifndef MC__TEXTCONF_H
#define MC__TEXTCONF_H

/*** typedefs(not structures) and defined constants **********************************************/

/*** enums ***************************************************************************************/

/*** structures declarations (and typedefs of structures)*****************************************/

/*** global variables defined in .c file *********************************************************/

/*** declarations of public functions ************************************************************/

extern void show_version (void);
extern void show_datadirs_extended (void);
extern void show_configure_options (void);

/*** inline functions ****************************************************************************/
#endif /* MC__TEXTCONF_H */
